histomicstk.annotations_and_masks
==================================

.. automodule:: histomicstk.annotations_and_masks
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::
    :maxdepth: 1

    Annotation database backup and sqlite parser <histomicstk.annotations_and_masks.annotation_database_parser.rst>
    Mosaic review gallery <histomicstk.annotations_and_masks.review_gallery.rst>
    Annotations to semantic segmentation masks <histomicstk.annotations_and_masks.annotations_to_semantic_segmentation_masks.rst>
    Annotations to object segmentation masks <histomicstk.annotations_and_masks.annotations_to_object_segmentation_masks.rst>
    Masks to annotations <histomicstk.annotations_and_masks.masks_to_annotations_handler.rst>
    Annotation and mask utilities <histomicstk.annotations_and_masks.annotation_and_mask_utils.rst>
    Polygon merger <histomicstk.annotations_and_masks.polygon_merger.rst>
